#ifndef NDS_OCTAVE_BUFFER_I
#define NDS_OCTAVE_BUFFER_I

//-----------------------------------------------------------------------
// Buffers
//-----------------------------------------------------------------------

%begin %{
#include "nds_buffer.hh"
using NDS::buffer;

%}

%{
static buffer::gps_second_type
buffer_gps_seconds_get( buffer* Value )
{
  return Value->Start( );
}

static buffer::gps_nanosecond_type
buffer_gps_nanoseconds_get( buffer* Value )
{
  return Value->StartNano( );
}

static octave_value
buffer_data_get( buffer* Value )
{
  const size_t                  SIZE( Value->Samples( ) );
  dim_vector                    dims( SIZE, 1 );
  NDS::swig_buffer_helper       sbh( *(Value) );
  void*                         dp( (void *)(&(sbh.data_vector( )[0])) );
  octave_value                  retval;

  switch( Value->DataType( ) )
  {
  case NDS::channel::DATA_TYPE_INT16:
    {
      int16NDArray arr(dims);
      memcpy((void *) arr.data(), dp, SIZE * sizeof(octave_int16));
      retval = arr;
    }
    break;
  case NDS::channel::DATA_TYPE_INT32:
    {
      int32NDArray arr(dims);
      memcpy((void *) arr.data(), dp, SIZE * sizeof(octave_int32));
      retval = arr;
    } break;
  case NDS::channel::DATA_TYPE_INT64:
    {
      int64NDArray arr(dims);
      memcpy((void *) arr.data(), dp, SIZE * sizeof(octave_int64));
      retval = arr;
    }
    break;
  case NDS::channel::DATA_TYPE_FLOAT32:
    {
      FloatNDArray arr(dims);
      memcpy((void *) arr.data(), dp, SIZE * sizeof(float));
      retval = arr;
    }
    break;
  case NDS::channel::DATA_TYPE_FLOAT64:
    {
      NDArray arr(dims);
      memcpy((void *) arr.data(), dp, SIZE * sizeof(double));
      retval = arr;
    }
    break;
  case NDS::channel::DATA_TYPE_COMPLEX32:
    {
      FloatComplexNDArray arr(dims);
      memcpy((void *) arr.data(), dp, SIZE * sizeof(double));
      retval = arr;
    }
    break;
  case NDS::channel::DATA_TYPE_UINT32:
    {
      uint32NDArray arr(dims);
      memcpy((void *) arr.data(), dp, SIZE * sizeof(octave_uint32));
      retval = arr;
    }
    break;
#if 0
  default:
    SWIG_exception(SWIG_TypeError, "Unknown NDS data type");
    break;
#endif /* 0 */
  }

  return retval;
}

static NDS::channel*
buffer_channel_get( NDS::buffer* Value )
{
  return Value;
}

static void
buffer_channel_set( buffer* Value, NDS::channel* Channel )
{
}

%}

%extend buffer {
  std::string __str__( ) {
    return $self->NameLong( );
  }

  const gps_second_type gps_seconds;
  const gps_second_type gps_nanoseconds;
  const octave_value data;
  channel channel;
}

%nds_vect_typemap(buffers_type, buffer);

#endif /* NDS_OCTAVE_BUFFER_I */
